// AppController.h -- interface for the UndoQueue controller class
//                    (actually, the only custom class here)

#import <Cocoa/Cocoa.h>

@interface AppController : NSObject
{
    // set by a checkbox, this controls whether we use the
    // notification-queue event-coalescing thing
    BOOL coalesceP;

    // this is our "model", which displays the number and the color in
    // a text field
    float thing;
    NSColor *color;

    // this is our 'view', where the color and value get displayed.
    // while tracking with coalesced undo turned on, temporary values
    // are displayed in parenthesis (e.g. (5) or (86))
    IBOutlet NSTextField *displayField;


    // The controls the user can fiddle with.  We need to have these
    // references so we can change their values when an undo happens
    IBOutlet NSSlider *slider;
    IBOutlet NSColorWell *colorWell;


    // The window will make an undo manager for us when an undo/redo
    // operation walks its way up the responder chain.
    IBOutlet NSWindow *window;


    // this notification queue is what's used to coalesce the
    // continuous- control actions into a single undoable operation.
    // During the drags notifications are posted to his queue,
    // coalesced on name and sender, and to be posted to the Real
    // notification center on idle (which means after the mouse button
    // is released
    NSNotificationQueue *undoQueue;

}


// set the value in our model.  This is hooked up to a slider.
- (IBAction) setThing: (id) sender;

// set the color in our model.  This is hooked up to a color well.
- (IBAction) setColor: (id) sender;

// purge the undo stack
- (IBAction) clearUndo: (id) sender;

// turn on/off the undo queueuing
- (IBAction) coalesceUndo: (id) sender;

@end // AppController

